package com.dbnt.faisp.main.userInfo.mapper;

import com.dbnt.faisp.main.userInfo.model.*;
import com.dbnt.faisp.main.userInfo.model.UserInoutLog;
import com.dbnt.faisp.main.userInfo.model.UserRequestLog;
import com.dbnt.faisp.main.userInfo.model.PersonnelStatus;
import com.dbnt.faisp.main.userInfo.model.UserEdu;
import com.dbnt.faisp.util.ParamMap;

import org.apache.ibatis.annotations.Mapper;

import java.util.List;

@Mapper
public interface UserInfoMapper {
  List<UserInfo> selectUserInfoList(UserInfo userInfo);

  Integer selectUserInfoListCnt(UserInfo userInfo);

  List<ParamMap> selectManagerList(ParamMap param);

  List<DashboardConfig> selectDashboardConfigList(Integer userSeq);

  List<UserInfo> selectPoliceList(UserInfo userInfo);

  Integer selectPoliceListCnt(UserInfo userInfo);

  List<UserInfoHistory> selectPoliceHisList(UserInfoHistory userInfoHistory);

  UserInfoHistory selectpoliceHistoryView(UserInfoHistory userInfoHistory);

  List<PersonnelStatus> selectPersonnelStatusList(PersonnelStatus personnelStatus);

  PersonnelStatus nowPersonnelStatus(String ogCd);

  UserInfo selectPoliceInfo(Integer userSeq);

  List<UserEdu> selectEduList(UserEdu userEdu);

  List<UserRequestLog> selectRequestLogList(UserRequestLog requestLog);

  Integer selectRequestLogListCnt(UserRequestLog requestLog);

  List<UserInoutLog> selectInoutLogList(UserInoutLog inoutLog);

  Integer selectInoutLogListCnt(UserInoutLog inoutLog);

  List<UserAlarm> selectAlarmList(UserAlarm userAlarm);
  Integer selectAlarmListCnt(UserAlarm userAlarm);
}
